import request from '@/utils/request'

const baseUrl = import.meta.env.VITE_APP_PRODUCTION_API

/**
 * 获取 生产批次 列表
 * @param {*} data
 * @returns
 */
export function listCheckoutInspection(query) {
  return request({
    url: baseUrl + '/business/beforeCheckoutVerify/list',
    method: 'get',
    params: query
  })
}

export function confirmInspection(data) {
  return request({
    url: baseUrl + '/business/beforeCheckoutVerify/confirm',
    method: 'post',
    data: data
  })
}

export function rejectInspection(data) {
  return request({
    url: baseUrl + '/business/beforeCheckoutVerify/reject',
    method: 'post',
    data: data
  })
}

export function checkFurnace(data) {
  return request({
    url: baseUrl + '/business/beforeCheckoutVerify/checkFurnace',
    method: 'post',
    data: data
  })
}
export function checkMultiplyFurnace(data) {
  return request({
    url: baseUrl + '/business/beforeCheckoutVerify/checkMultiplyFurnace',
    method: 'post',
    data: data
  })
}